netapp_ontap.models.container_response_records_volumes API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.container_response_records_volumes`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ContainerResponseRecordsVolumesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ContainerResponseRecordsVolumes object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `exclude_aggregates: List[ContainerVolumesExcludeAggregates] GET POST PATCH`

    A list of aggregates to exclude when determining the placement of the volume.

  `flexcache: ContainerVolumesFlexcache GET POST PATCH`

    The FlexCache origin volume.

  `name: str GET POST PATCH`

    Volume name. The name of volume must start with an alphabetic character (a to z or A to Z) or an underscore (_). The name must be 197 or fewer characters in length for FlexGroup volumes, and 203 or fewer characters in length for all other types of volumes. Volume names must be unique within an SVM. Required on POST.

    Example: vol_cs_dept

  `nas: ConsistencyGroupNas GET POST PATCH`

    The nas field of the container_response_records_volumes.

  `qos: ConsistencyGroupQos POST`

    The qos field of the container_response_records_volumes.

  `s3_bucket: ContainerResponseRecordsVolumesS3Bucket GET POST PATCH`

    The S3 bucket

  `scale_out: bool POST`

    Denotes a Flexgroup.

  `snaplock: ContainerVolumeSnaplock POST`

    The snaplock field of the container_response_records_volumes.

  `snapshot_locking_enabled: bool GET POST PATCH`

    Specifies whether or not snapshot copy locking is enabled on the volume.

  `snapshot_policy: SnapshotPolicy GET POST PATCH`

    The snapshot_policy field of the container_response_records_volumes.

  `space: ContainerVolumesSpace POST`

    The space field of the container_response_records_volumes.

  `storage_service: ContainerVolumesStorageService GET POST PATCH`

    Determines the placement of the volume that is to be provisioned.

  `tiering: ConsistencyGroupTiering POST`

    The tiering field of the container_response_records_volumes.

  `use_mirrored_aggregates: bool POST`

    Specifies whether mirrored aggregates are selected when provisioning the volume. Only mirrored aggregates are used if this parameter is set to true and only unmirrored aggregates are used if this parameter is set to false. The default value is true for a MetroCluster configuration and is false for a non-MetroCluster configuration.